/*
** ----------------------------------------------------------------------
** DSGYLIB.C: LIBRARY OF ROUTINES USED BY DUMPSEGY
**
**              VERSION: V1.0
**          ORIGIN DATE: 12/8/92
**             COMPILER: BORLAND C/C++ V3.1
**
** MODIFICATION HISTORY:
**
**               AUTHOR: F.N. ZIHLMAN, USGS
**                       BRANCH OF PETROLEUM GEOLOGY, GEOPHYSICS GROUP
**                       P.O. BOX 25046, MS 960
**                       DENVER, CO 80225
**                       303-236-5741
** ---------------------------------------------------------------------
*/

#ifndef DUMPSEGY_H
#define DUMPSEGY_H 1
#include "dumpsegy.h"
#endif

/*
** --------------------------------------------------------------------
** Usage: displays program usage information.
** No arguments.
** --------------------------------------------------------------------
*/

void Usage(void)
{
  printf("\nUSAGE:  dumpsegy {file name} {-e} {-b} {-t} {-n} {-v} {-c} {-f file} {-r}\n");
  printf("\n{file name} MUST be provided, all other parameters are optional.\n\n");
  printf("-e:                        - display EBCDIC header record.\n");
  printf("-b:                        - display BINARY header record.\n");
  printf("-t:                        - display individual trace header per trace\n");
  printf("                             selected.\n");
  printf("-v:                        - display actual SEG-Y sample value in decimal.\n");
  printf("-n:                        - display all information EXCEPT trace samples.\n");
  printf("-c:                        - copy data to an output file in binary format.\n");
  printf("                             This option may be used to create a SEG-Y\n");
  printf("                             file containing a subset of the original SEG-Y\n");
  printf("                             file.\n");
  printf("-f {file name}:            - redirect output to a file.\n");
  printf("-r {start:stop:increment}: - sequential range of traces to display,\n");
  printf("                             with an optional increment.\n\n");
  printf("The -v and -c options are mutually exclusive and will cause DUMPSEGY to exit.\n\n");
  printf("Optional parameters may be entered in any order.\n\n");
  exit(1);
}

/*
** --------------------------------------------------------------------
** GetCmdLine: parses command line arguments
**
** cmdLine structure is filled from command line arguments
*/
void GetCmdLine(CMDLINE *cmdLine,int argc,char *argv[])
{
  int i;
  char *ptr;

  for(i=2;i<argc;i++)
     {
       if(((strcmp(argv[i],"-e"))==0)||((strcmp(argv[i],"-E"))==0))
	 cmdLine->e=TRUE;
       if(((strcmp(argv[i],"-b"))==0)||((strcmp(argv[i],"-B"))==0))
	 cmdLine->b=TRUE;
       if(((strcmp(argv[i],"-t"))==0)||((strcmp(argv[i],"-T"))==0))
	 cmdLine->t=TRUE;
       if(((strcmp(argv[i],"-n"))==0)||((strcmp(argv[i],"-N"))==0))
	 cmdLine->n=TRUE;
       if(((strcmp(argv[i],"-v"))==0)||((strcmp(argv[i],"-V"))==0))
	 {
	   if(cmdLine->c)
	     {
	       Usage();
	       exit(1);
	     }
	   cmdLine->v=TRUE;
	 }
       if(((strcmp(argv[i],"-c"))==0)||((strcmp(argv[i],"-C"))==0))
	 {
	   if(cmdLine->v)
	     {
	       Usage();
	       exit(1);
	     }
	   cmdLine->c=TRUE;
	 }
       if(((strcmp(argv[i],"-f"))==0)||((strcmp(argv[i],"-F"))==0))
	 strcpy(cmdLine->outputFileName,argv[i+1]);
       if(((strcmp(argv[i],"-r"))==0)||((strcmp(argv[i],"-R"))==0))
	 {
	   cmdLine->r=TRUE;
	   ptr=strtok(argv[i+1],":");
	   if(ptr!=NULL)
	     {
	       cmdLine->firstTrace=atol(ptr);
	       ptr=strtok(NULL,":");
	       if(ptr!=NULL)
		 {
		   cmdLine->lastTrace=atol(ptr);
		   ptr=strtok(NULL,":");
		   if(ptr!=NULL)
		     cmdLine->increment=atol(ptr);
		 }
	       else
		 {
		   fprintf(stderr,"BAD TRACE RANGE ENTERED\n");
		   exit(1);
		 }
	     }
	   else
	     {
	       fprintf(stderr,"BAD TRACE RANGE ENTERED\n");
	       exit(1);
	     }

	   if(((cmdLine->increment>0L)&&
	      (cmdLine->firstTrace>cmdLine->lastTrace))||
	      ((cmdLine->increment<0L)&&
	       (cmdLine->firstTrace<cmdLine->lastTrace))||
	       (cmdLine->increment==0L))
	     {
	       fprintf(stderr,"BAD TRACE RANGE OR INCREMENT ENTERED\n");
	       exit(1);
	     }
	 }
     }
/*
     printf("e               %d\n",cmdLine->e);
     printf("b               %d\n",cmdLine->b);
     printf("t               %d\n",cmdLine->t);
     printf("v               %d\n",cmdLine->v);
     printf("n               %d\n",cmdLine->n);
     printf("c               %d\n",cmdLine->c);
     printf("r               %d\n",cmdLine->r);
     printf("firstTrace      %ld\n",cmdLine->firstTrace);
     printf("lastTrace       %ld\n",cmdLine->lastTrace);
     printf("increment       %ld\n",cmdLine->increment);
     printf("outputFileName: %s\n",cmdLine->outputFileName);
*/
}

/*
** --------------------------------------------------------------------
** Continue: queries the user as to continue the program or exit.
** no arguments
** --------------------------------------------------------------------
*/
void Continue(void)
{
  char ch;

  printf("PRESS <CR> TO CONTINUE...X<CR> TO EXIT\n");
  ch=getchar();
  fflush(stdin);
  if(toupper(ch)=='X')
     exit(0);
}

/*
** --------------------------------------------------------------------
** PrintFileInfo: display information about the SEG-Y file opened for
**                processing.
** no return arguments.
** --------------------------------------------------------------------
*/
void PrintFileInfo(CMDLINE *cmdLine,FILE_INFO *fileInfo)
{
      fprintf(cmdLine->outputFile,"========== FILE INFORMATION =========\n");
      fprintf(cmdLine->outputFile,"             file: %s\n\n",fileInfo->fileName);
      fprintf(cmdLine->outputFile,"      sample rate: %6.1f microsec\n",fileInfo->sampleRate);
      fprintf(cmdLine->outputFile,"samples per trace: %6d\n",fileInfo->numberOfSamples);
      fprintf(cmdLine->outputFile,"      data length: %6d msec\n",fileInfo->maxTime);
      fprintf(cmdLine->outputFile,"  bytes per trace: %6d\n",fileInfo->bytesPerTrace);
      fprintf(cmdLine->outputFile,"    bytes in file: %6ld\n",fileInfo->bytesInFile);
      fprintf(cmdLine->outputFile,"   traces in file: %6d\n\n",fileInfo->tracesInFile);
}

/*
** --------------------------------------------------------------------
** PrintEBCDICHeader: display decoded EBCDIC header information.
** no return arguments
** --------------------------------------------------------------------
*/
void PrintEBCDICHeader(FILE *outputFile,EBCDIC *ebcdicHdr)
{
  int i;

  for(i=0;i<40;i++)
     {
       #ifdef UNIX_SYSTEM
	 fprintf(outputFile,"%s\n",ebcdicHdr->table[i]);
       #endif
       #ifdef DOS_SYSTEM
	 fprintf(outputFile,"%s",ebcdicHdr->table[i]);
       #endif
       if((outputFile==stdout)&&((i==19)||(i==39)))
	 {
	   Continue();
	 }
     }
  fprintf(outputFile,"\n");
}

/*
** --------------------------------------------------------------------
** PrintBinaryHeader: print decoded binary header.
** no return arguments.
** --------------------------------------------------------------------
*/
void PrintBinaryHeader(FILE *outputFile,BINHEADER *binaryHdr)
{
  fprintf(outputFile,"[3201 - 3204] jobID                      %8ld           %08lx\n",binaryHdr->jobID,binaryHdr->jobID);
  fprintf(outputFile,"[3205 - 3208] lineNumber                 %8ld	    %08lx\n",binaryHdr->lineNumber,binaryHdr->lineNumber);
  fprintf(outputFile,"[3209 - 3212] reelNumber                 %8ld	    %08lx\n",binaryHdr->reelNumber,binaryHdr->reelNumber);
  fprintf(outputFile,"[3213 - 3214] tracesPerRecord            %8d	    %04x\n",binaryHdr->tracesPerRecord,binaryHdr->tracesPerRecord);
  fprintf(outputFile,"[3215 - 3216] auxTracesPerRecord         %8d	    %04x\n",binaryHdr->auxTracesPerRecord,binaryHdr->auxTracesPerRecord);
  fprintf(outputFile,"[3217 - 3218] sampleRateReel             %8d	    %04x\n",binaryHdr->sampleRateReel,binaryHdr->sampleRateReel);
  fprintf(outputFile,"[3219 - 3220] sampleRateOrig             %8d	    %04x\n",binaryHdr->sampleRateOrig,binaryHdr->sampleRateOrig);
  fprintf(outputFile,"[3221 - 3222] samplesPerTraceReel        %8d	    %04x\n",binaryHdr->samplesPerTraceReel,binaryHdr->samplesPerTraceReel);
  fprintf(outputFile,"[3223 - 3224] samplesPerTraceOrig        %8d	    %04x\n",binaryHdr->samplesPerTraceOrig,binaryHdr->samplesPerTraceOrig);
  fprintf(outputFile,"[3225 - 3226] dataFormatCode             %8d	    %04x\n",binaryHdr->dataFormatCode,binaryHdr->dataFormatCode);
  fprintf(outputFile,"[3227 - 3228] CDPfold                    %8d	    %04x\n",binaryHdr->CDPfold,binaryHdr->CDPfold);
  fprintf(outputFile,"[3229 - 3230] traceSortCode              %8d	    %04x\n",binaryHdr->traceSortCode,binaryHdr->traceSortCode);
  fprintf(outputFile,"[3231 - 3232] verticalSumCode            %8d	    %04x\n",binaryHdr->verticalSumCode,binaryHdr->verticalSumCode);
  fprintf(outputFile,"[3233 - 3234] sweepFreqStart             %8d	    %04x\n",binaryHdr->sweepFreqStart,binaryHdr->sweepFreqStart);
  fprintf(outputFile,"[3235 - 3236] sweepFreqEnd               %8d	    %04x\n",binaryHdr->sweepFreqEnd,binaryHdr->sweepFreqEnd);
  fprintf(outputFile,"[3237 - 3238] sweepLength                %8d	    %04x\n",binaryHdr->sweepLength,binaryHdr->sweepLength);
  fprintf(outputFile,"[3239 - 3240] sweepTypeCode              %8d	    %04x\n",binaryHdr->sweepTypeCode,binaryHdr->sweepTypeCode);
  fprintf(outputFile,"[3241 - 3242] sweepChannelTraceNumber    %8d	    %04x\n",binaryHdr->sweepChannelTraceNumber,binaryHdr->sweepChannelTraceNumber);
  fprintf(outputFile,"[3243 - 3244] sweepTraceTaperLengthStart %8d	    %04x\n",binaryHdr->sweepTraceTaperLengthStart,binaryHdr->sweepTraceTaperLengthStart);
  fprintf(outputFile,"[3245 - 3246] sweepTraceTaperLengthEnd   %8d	    %04x\n",binaryHdr->sweepTraceTaperLengthEnd,binaryHdr->sweepTraceTaperLengthEnd);
  fprintf(outputFile,"[3247 - 3248] taperType                  %8d	    %04x\n",binaryHdr->taperType,binaryHdr->taperType);

  if(outputFile==stdout)
    {
      Continue();
    }

  fprintf(outputFile,"[3249 - 3250] correlatedData             %8d	    %04x\n",binaryHdr->correlatedData,binaryHdr->correlatedData);
  fprintf(outputFile,"[3251 - 3252] binaryGainRecovered        %8d	    %04x\n",binaryHdr->binaryGainRecovered,binaryHdr->binaryGainRecovered);
  fprintf(outputFile,"[3253 - 3254] amplitudeRecovery          %8d	    %04x\n",binaryHdr->amplitudeRecovery,binaryHdr->amplitudeRecovery);
  fprintf(outputFile,"[3255 - 3256] measurementSystem          %8d	    %04x\n",binaryHdr->measurementSystem,binaryHdr->measurementSystem);
  fprintf(outputFile,"[3257 - 3258] impulseSignalPolarity      %8d	    %04x\n",binaryHdr->impulseSignalPolarity,binaryHdr->impulseSignalPolarity);
  fprintf(outputFile,"[3259 - 3260] vibratoryPolarityCode      %8d	    %04x\n\n",binaryHdr->vibratoryPolarityCode,binaryHdr->vibratoryPolarityCode);

  if(outputFile==stdout)
    {
      Continue();
    }
}

/*
** --------------------------------------------------------------------
** PrintTraceHeader: display decoded trace header.
** no return arguments.
** --------------------------------------------------------------------
*/
void PrintTraceHeader(FILE *outputFile,TRCHEADER *traceHdr,long bytesPerTrace, long traceNumber)
{
  long byteCount;

  byteCount=(3600L+(bytesPerTrace*(traceNumber-1L)));
  fprintf(outputFile,"[%6ld - %6ld] traceSequenceNumberLine   %8ld          %08lx\n",byteCount+1,byteCount+4,traceHdr->traceSequenceNumberLine,traceHdr->traceSequenceNumberLine);
  fprintf(outputFile,"[%6ld - %6ld] traceSequenceNumberReel   %8ld          %08lx\n",byteCount+5,byteCount+8,traceHdr->traceSequenceNumberReel,traceHdr->traceSequenceNumberReel);
  fprintf(outputFile,"[%6ld - %6ld] origFieldRecordNumber     %8ld          %08lx\n",byteCount+9,byteCount+12,traceHdr->origFieldRecordNumber,traceHdr->origFieldRecordNumber);
  fprintf(outputFile,"[%6ld - %6ld] fieldRecordTraceNumber    %8ld          %08lx\n",byteCount+13,byteCount+16,traceHdr->fieldRecordTraceNumber,traceHdr->fieldRecordTraceNumber);
  fprintf(outputFile,"[%6ld - %6ld] energySourcePt            %8ld          %08lx\n",byteCount+17,byteCount+20,traceHdr->energySourcePt,traceHdr->energySourcePt);
  fprintf(outputFile,"[%6ld - %6ld] cdpNumber                 %8ld          %08lx\n",byteCount+21,byteCount+24,traceHdr->cdpNumber,traceHdr->cdpNumber);
  fprintf(outputFile,"[%6ld - %6ld] traceCdpNumber            %8ld          %08lx\n",byteCount+25,byteCount+28,traceHdr->traceCdpNumber,traceHdr->traceCdpNumber);
  fprintf(outputFile,"[%6ld - %6ld] traceIdNumber             %8d          %04x\n",byteCount+29,byteCount+30,traceHdr->traceIdNumber,traceHdr->traceIdNumber);
  fprintf(outputFile,"[%6ld - %6ld] verticallySummedTraces    %8d          %04x\n",byteCount+31,byteCount+32,traceHdr->verticallySummedTraces,traceHdr->verticallySummedTraces);
  fprintf(outputFile,"[%6ld - %6ld] horizontallyStackedTraces %8d          %04x\n",byteCount+33,byteCount+34,traceHdr->horizontallyStackedTraces,traceHdr->horizontallyStackedTraces);
  fprintf(outputFile,"[%6ld - %6ld] dataUse                   %8d          %04x\n",byteCount+35,byteCount+36,traceHdr->dataUse,traceHdr->dataUse);
  fprintf(outputFile,"[%6ld - %6ld] sourceToReceiver          %8ld          %08lx\n",byteCount+37,byteCount+40,traceHdr->sourceToReceiver,traceHdr->sourceToReceiver);
  fprintf(outputFile,"[%6ld - %6ld] receiverElevation         %8ld          %08lx\n",byteCount+41,byteCount+44,traceHdr->receiverElevation,traceHdr->receiverElevation);
  fprintf(outputFile,"[%6ld - %6ld] sourceSurfaceElevation    %8ld          %08lx\n",byteCount+45,byteCount+48,traceHdr->sourceSurfaceElevation,traceHdr->sourceSurfaceElevation);
  fprintf(outputFile,"[%6ld - %6ld] sourceDepth               %8ld          %08lx\n",byteCount+49,byteCount+52,traceHdr->sourceDepth,traceHdr->sourceDepth);
  fprintf(outputFile,"[%6ld - %6ld] receiverDatumElevation    %8ld          %08lx\n",byteCount+53,byteCount+56,traceHdr->receiverDatumElevation,traceHdr->receiverDatumElevation);
  fprintf(outputFile,"[%6ld - %6ld] sourceDatumElevation      %8ld          %08lx\n",byteCount+57,byteCount+60,traceHdr->sourceDatumElevation,traceHdr->sourceDatumElevation);
  fprintf(outputFile,"[%6ld - %6ld] sourceWaterDepth          %8ld          %08lx\n",byteCount+61,byteCount+64,traceHdr->sourceWaterDepth,traceHdr->sourceWaterDepth);
  fprintf(outputFile,"[%6ld - %6ld] groupWaterDepth           %8ld          %08lx\n",byteCount+65,byteCount+68,traceHdr->groupWaterDepth,traceHdr->groupWaterDepth);
  fprintf(outputFile,"[%6ld - %6ld] elevationScalar           %8d          %04x\n",byteCount+69,byteCount+70,traceHdr->elevationScalar,traceHdr->elevationScalar);
  fprintf(outputFile,"[%6ld - %6ld] coordinateScalar          %8d          %04x\n",byteCount+71,byteCount+72,traceHdr->coordinateScalar,traceHdr->coordinateScalar);
  fprintf(outputFile,"[%6ld - %6ld] sourceXCoordinate         %8ld          %08lx\n",byteCount+73,byteCount+76,traceHdr->sourceXCoordinate,traceHdr->sourceXCoordinate);

  if(outputFile==stdout)
    {
      Continue();
    }

  fprintf(outputFile,"[%6ld - %6ld] sourceYCoordinate         %8ld          %08lx\n",byteCount+77,byteCount+80,traceHdr->sourceYCoordinate,traceHdr->sourceYCoordinate);
  fprintf(outputFile,"[%6ld - %6ld] groupXCoordinate          %8ld          %08lx\n",byteCount+81,byteCount+84,traceHdr->groupXCoordinate,traceHdr->groupXCoordinate);
  fprintf(outputFile,"[%6ld - %6ld] groupYCoordinate          %8ld          %08lx\n",byteCount+85,byteCount+88,traceHdr->groupYCoordinate,traceHdr->groupYCoordinate);
  fprintf(outputFile,"[%6ld - %6ld] coordinateUnits           %8d          %04x\n",byteCount+89,byteCount+90,traceHdr->coordinateUnits,traceHdr->coordinateUnits);
  fprintf(outputFile,"[%6ld - %6ld] weatheringVelocity        %8d          %04x\n",byteCount+91,byteCount+92,traceHdr->weatheringVelocity,traceHdr->weatheringVelocity);
  fprintf(outputFile,"[%6ld - %6ld] subWeatheringVelocity     %8d          %04x\n",byteCount+93,byteCount+94,traceHdr->subWeatheringVelocity,traceHdr->subWeatheringVelocity);
  fprintf(outputFile,"[%6ld - %6ld] sourceUpholeTime          %8d          %04x\n",byteCount+95,byteCount+96,traceHdr->sourceUpholeTime,traceHdr->sourceUpholeTime);
  fprintf(outputFile,"[%6ld - %6ld] groupUpholeTime           %8d          %04x\n",byteCount+97,byteCount+98,traceHdr->groupUpholeTime,traceHdr->groupUpholeTime);
  fprintf(outputFile,"[%6ld - %6ld] sourceStaticCorrection    %8d          %04x\n",byteCount+99,byteCount+100,traceHdr->sourceStaticCorrection,traceHdr->sourceStaticCorrection);
  fprintf(outputFile,"[%6ld - %6ld] groupStaticCorrection     %8d          %04x\n",byteCount+101,byteCount+102,traceHdr->groupStaticCorrection,traceHdr->groupStaticCorrection);
  fprintf(outputFile,"[%6ld - %6ld] totalStaticApplied        %8d          %04x\n",byteCount+103,byteCount+104,traceHdr->totalStaticApplied,traceHdr->totalStaticApplied);
  fprintf(outputFile,"[%6ld - %6ld] lagTimeA                  %8d          %04x\n",byteCount+105,byteCount+106,traceHdr->lagTimeA,traceHdr->lagTimeA);
  fprintf(outputFile,"[%6ld - %6ld] lagTimeB                  %8d          %04x\n",byteCount+107,byteCount+108,traceHdr->lagTimeB,traceHdr->lagTimeB);
  fprintf(outputFile,"[%6ld - %6ld] delayRecordingTime        %8d          %04x\n",byteCount+109,byteCount+110,traceHdr->delayRecordingTime,traceHdr->delayRecordingTime);
  fprintf(outputFile,"[%6ld - %6ld] muteTimeStart             %8d          %04x\n",byteCount+111,byteCount+112,traceHdr->muteTimeStart,traceHdr->muteTimeStart);
  fprintf(outputFile,"[%6ld - %6ld] muteTimeEnd               %8d          %04x\n",byteCount+113,byteCount+114,traceHdr->muteTimeEnd,traceHdr->muteTimeEnd);
  fprintf(outputFile,"[%6ld - %6ld] numberOfSamples           %8d          %04x\n",byteCount+115,byteCount+116,traceHdr->numberOfSamples,traceHdr->numberOfSamples);
  fprintf(outputFile,"[%6ld - %6ld] sampleInterval            %8d          %04x\n",byteCount+117,byteCount+118,traceHdr->sampleInterval,traceHdr->sampleInterval);
  fprintf(outputFile,"[%6ld - %6ld] gainType                  %8d          %04x\n",byteCount+119,byteCount+120,traceHdr->gainType,traceHdr->gainType);
  fprintf(outputFile,"[%6ld - %6ld] gainConstant              %8d          %04x\n",byteCount+121,byteCount+122,traceHdr->gainConstant,traceHdr->gainConstant);
  fprintf(outputFile,"[%6ld - %6ld] initialGain               %8d          %04x\n",byteCount+123,byteCount+124,traceHdr->initialGain,traceHdr->initialGain);
  fprintf(outputFile,"[%6ld - %6ld] correlated                %8d          %04x\n",byteCount+125,byteCount+126,traceHdr->correlated,traceHdr->correlated);

  if(outputFile==stdout)
    {
      Continue();
    }

  fprintf(outputFile,"[%6ld - %6ld] sweepFrequencyStart       %8d          %04x\n",byteCount+127,byteCount+128,traceHdr->sweepFrequencyStart,traceHdr->sweepFrequencyStart);
  fprintf(outputFile,"[%6ld - %6ld] sweepFrequencyEnd         %8d          %04x\n",byteCount+129,byteCount+130,traceHdr->sweepFrequencyEnd,traceHdr->sweepFrequencyEnd);
  fprintf(outputFile,"[%6ld - %6ld] sweepLength               %8d          %04x\n",byteCount+131,byteCount+132,traceHdr->sweepLength,traceHdr->sweepLength);
  fprintf(outputFile,"[%6ld - %6ld] sweepType                 %8d          %04x\n",byteCount+133,byteCount+134,traceHdr->sweepType,traceHdr->sweepType);
  fprintf(outputFile,"[%6ld - %6ld] sweepTraceTaperStart      %8d          %04x\n",byteCount+135,byteCount+136,traceHdr->sweepTraceTaperStart,traceHdr->sweepTraceTaperStart);
  fprintf(outputFile,"[%6ld - %6ld] sweepTraceTaperEnd        %8d          %04x\n",byteCount+137,byteCount+138,traceHdr->sweepTraceTaperEnd,traceHdr->sweepTraceTaperEnd);
  fprintf(outputFile,"[%6ld - %6ld] taperType                 %8d          %04x\n",byteCount+139,byteCount+140,traceHdr->taperType,traceHdr->taperType);
  fprintf(outputFile,"[%6ld - %6ld] aliasFilterFrequency      %8d          %04x\n",byteCount+141,byteCount+142,traceHdr->aliasFilterFrequency,traceHdr->aliasFilterFrequency);
  fprintf(outputFile,"[%6ld - %6ld] aliasFilterSlope          %8d          %04x\n",byteCount+143,byteCount+144,traceHdr->aliasFilterSlope,traceHdr->aliasFilterSlope);
  fprintf(outputFile,"[%6ld - %6ld] notchFilterFrequency      %8d          %04x\n",byteCount+145,byteCount+146,traceHdr->notchFilterFrequency,traceHdr->notchFilterFrequency);
  fprintf(outputFile,"[%6ld - %6ld] notchFilterSlope          %8d          %04x\n",byteCount+147,byteCount+148,traceHdr->notchFilterSlope,traceHdr->notchFilterSlope);
  fprintf(outputFile,"[%6ld - %6ld] lowCutFrequency           %8d          %04x\n",byteCount+149,byteCount+150,traceHdr->lowCutFrequency,traceHdr->lowCutFrequency);
  fprintf(outputFile,"[%6ld - %6ld] highCutFrequency          %8d          %04x\n",byteCount+151,byteCount+152,traceHdr->highCutFrequency,traceHdr->highCutFrequency);
  fprintf(outputFile,"[%6ld - %6ld] lowCutSlope               %8d          %04x\n",byteCount+153,byteCount+154,traceHdr->lowCutSlope,traceHdr->lowCutSlope);
  fprintf(outputFile,"[%6ld - %6ld] highCutSlope              %8d          %04x\n",byteCount+155,byteCount+156,traceHdr->highCutSlope,traceHdr->highCutSlope);
  fprintf(outputFile,"[%6ld - %6ld] yearRecorded              %8d          %04x\n",byteCount+157,byteCount+158,traceHdr->yearRecorded,traceHdr->yearRecorded);
  fprintf(outputFile,"[%6ld - %6ld] dayOfYear                 %8d          %04x\n",byteCount+159,byteCount+160,traceHdr->dayOfYear,traceHdr->dayOfYear);
  fprintf(outputFile,"[%6ld - %6ld] hourOfDay                 %8d          %04x\n",byteCount+161,byteCount+162,traceHdr->hourOfDay,traceHdr->hourOfDay);
  fprintf(outputFile,"[%6ld - %6ld] minuteOfHour              %8d          %04x\n",byteCount+163,byteCount+164,traceHdr->minuteOfHour,traceHdr->minuteOfHour);
  fprintf(outputFile,"[%6ld - %6ld] secondOfMinute            %8d          %04x\n",byteCount+165,byteCount+166,traceHdr->secondOfMinute,traceHdr->secondOfMinute);
  fprintf(outputFile,"[%6ld - %6ld] timeBasisCode             %8d          %04x\n",byteCount+167,byteCount+168,traceHdr->timeBasisCode,traceHdr->timeBasisCode);
  fprintf(outputFile,"[%6ld - %6ld] traceWeightingFactor      %8d          %04x\n",byteCount+169,byteCount+170,traceHdr->traceWeightingFactor,traceHdr->traceWeightingFactor);

  if(outputFile==stdout)
    {
      Continue();
    }

  fprintf(outputFile,"[%6ld - %6ld] geophoneNumberRollSwitch1 %8d          %04x\n",byteCount+171,byteCount+172,traceHdr->geophoneNumberRollSwitch1,traceHdr->geophoneNumberRollSwitch1);
  fprintf(outputFile,"[%6ld - %6ld] geophoneNumberTrace1      %8d          %04x\n",byteCount+173,byteCount+174,traceHdr->geophoneNumberTrace1,traceHdr->geophoneNumberTrace1);
  fprintf(outputFile,"[%6ld - %6ld] geophoneNumberLastTrace   %8d          %04x\n",byteCount+175,byteCount+176,traceHdr->geophoneNumberLastTrace,traceHdr->geophoneNumberLastTrace);
  fprintf(outputFile,"[%6ld - %6ld] gapSize                   %8d          %04x\n",byteCount+177,byteCount+178,traceHdr->gapSize,traceHdr->gapSize);
  fprintf(outputFile,"[%6ld - %6ld] overTravel                %8d          %04x\n\n",byteCount+179,byteCount+180,traceHdr->overTravel,traceHdr->overTravel);

  if(outputFile==stdout)
    {
      Continue();
    }
}

/*
** --------------------------------------------------------------------
** PrintSamples: displays sample value as either it's SEG-Y hexadecimal
**               value or it's decoded floating point value.
** no return arguments
** --------------------------------------------------------------------
*/
void PrintSamples(CMDLINE *cmdLine,unsigned char *sampleBuffer)
{
  if(cmdLine->v==FALSE)
    fprintf(cmdLine->outputFile,"%02x%02x %02x%02x ",*(sampleBuffer),*(sampleBuffer+1),
	    *(sampleBuffer+2),*(sampleBuffer+3));
  else
    fprintf(cmdLine->outputFile,"%+.6e ",(CalcSampleValue(sampleBuffer)));
}
