/*
*************************************************************************
* SEGYLIBH.H: Header file for the seismic function library SEGYLIB.C V1.0
*
*              VERSION: V1.0
*          ORIGIN DATE: 5/14/92
*             COMPILER: BORLAND C/C++ V3.0
* MODIFICATION HISTORY:
*                       10/30/92 - added Get4Bytes function
*                       10/30/92 - added Get2Bytes function
*                       10/30/92 - modified TRCSAMPLES structure member
*                                  cdpNumber from int to long
*                       10/30/92 - added TRCSAMPLES structure member
*                                  long cdpTrace - trace number within a
*                                  CDP
*                       10/30/92 - GoToTrace argument traceNumber changed
*                                  from int to long
*                       10/30/92 - GetCDP argument *cdp changed
*                                  from int to long
*                       11/4/92  - GoToByte unsigned long argument changed
*                                  to long
*
*               AUTHOR: F.N. ZIHLMAN, USGS
*                       BRANCH OF PETROLEUM GEOLOGY, GEOPHYSICS GROUP
*                       P.O. BOX 25046, MS 960
*                       DENVER, CO 80225
*                       303-236-5741
*************************************************************************
*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define TRUE 1
#define FALSE 0
#define ESC 27
#define S_BUFF_SIZE 2
#define L_BUFF_SIZE 4
#define LEFT_SHIFT_BITS 8
#define CDP 21                /* BYTE LOCATIONS FOR */
#define SAMPLERATE 117        /* THESE TRACE HEADER */
#define NUMBERSAMPLES 115     /* VALUES             */
#define CDP_TRACE 25
#define FFID 9
#define SAMPLE1 241           /* LOCATION OF 1ST SAMPLE IN ANY TRACE */
#define MAXSAMPLES 6000
#define EBCDICHEADER 3200     /* SIZE OF EBCDIC HEADER IN BYTES */
#define BINARYHEADER 400      /* SIZE OF BINARY HEADER IN BYTES */
#define TRACEHEADER 240       /* SIZE OF TRACE HEADER IN BYTES  */

/*
*************************************************************************
* DATA STRUCTURE DEFINITIONS
*************************************************************************
*/
/*
typedef struct
	{
	  FILE  *pSegYIn;
	  char  filePath[61];
	  char  fileName[13];
	  float sampleRate;
	  int   numberOfSamples;
	  int   maxTime;
	  long  bytesPerTrace;
	  long  bytesInFile;
	  long  tracesInFile;
	} FILE_INFO;
*/

typedef struct
	{
	  long cdpNumber;
	  long cdpTrace;
	  long ffid;
	  float sampleRate;
	  int numberOfSamples;
	  float avgValue;
	  int   scaling;
	  float relativeAmp;
	  float values[MAXSAMPLES];
	}TRCSAMPLES;

typedef struct
	{
	  char table[40][81];
	}EBCDIC;

typedef struct
	{
	  long jobID;
	  long lineNumber;
	  long reelNumber;
	  int  tracesPerRecord;
	  int  auxTracesPerRecord;
	  int  sampleRateReel;
	  int  sampleRateOrig;
	  int  samplesPerTraceReel;
	  int  samplesPerTraceOrig;
	  int  dataFormatCode;
	  int  CDPfold;
	  int  traceSortCode;
	  int  verticalSumCode;
	  int  sweepFreqStart;
	  int  sweepFreqEnd;
	  int  sweepLength;
	  int  sweepTypeCode;
	  int  sweepChannelTraceNumber;
	  int  sweepTraceTaperLengthStart;
	  int  sweepTraceTaperLengthEnd;
	  int  taperType;
	  int  correlatedData;
	  int  binaryGainRecovered;
	  int  amplitudeRecovery;
	  int  measurementSystem;
	  int  impulseSignalPolarity;
	  int  vibratoryPolarityCode;
	} BINHEADER;

typedef struct
	{
	  long traceSequenceNumberLine;
	  long traceSequenceNumberReel;
	  long origFieldRecordNumber;
	  long fieldRecordTraceNumber;
	  long energySourcePt;
	  long cdpNumber;
	  long traceCdpNumber;
	  int  traceIdNumber;
	  int  verticallySummedTraces;
	  int  horizontallyStackedTraces;
	  int  dataUse;
	  long sourceToReceiver;
	  long receiverElevation;
	  long sourceSurfaceElevation;
	  long sourceDepth;
	  long receiverDatumElevation;
	  long sourceDatumElevation;
	  long sourceWaterDepth;
	  long groupWaterDepth;
	  int  elevationScalar;
	  int  coordinateScalar;
	  long sourceXCoordinate;
	  long sourceYCoordinate;
	  long groupXCoordinate;
	  long groupYCoordinate;
	  int  coordinateUnits;
	  int  weatheringVelocity;
	  int  subWeatheringVelocity;
	  int  sourceUpholeTime;
	  int  groupUpholeTime;
	  int  sourceStaticCorrection;
	  int  groupStaticCorrection;
	  int  totalStaticApplied;
	  int  lagTimeA;
	  int  lagTimeB;
	  int  delayRecordingTime;
	  int  muteTimeStart;
	  int  muteTimeEnd;
	  int  numberOfSamples;
	  int  sampleInterval;
	  int  gainType;
	  int  gainConstant;
	  int  initialGain;
	  int  correlated;
	  int  sweepFrequencyStart;
	  int  sweepFrequencyEnd;
	  int  sweepLength;
	  int  sweepType;
	  int  sweepTraceTaperStart;
	  int  sweepTraceTaperEnd;
	  int  taperType;
	  int  aliasFilterFrequency;
	  int  aliasFilterSlope;
	  int  notchFilterFrequency;
	  int  notchFilterSlope;
	  int  lowCutFrequency;
	  int  highCutFrequency;
	  int  lowCutSlope;
	  int  highCutSlope;
	  int  yearRecorded;
	  int  dayOfYear;
	  int  hourOfDay;
	  int  minuteOfHour;
	  int  secondOfMinute;
	  int  timeBasisCode;
	  int  traceWeightingFactor;
	  int  geophoneNumberRollSwitch1;
	  int  geophoneNumberTrace1;
	  int  geophoneNumberLastTrace;
	  int  gapSize;
	  int  overTravel;
	} TRCHEADER;

/*
*************************************************************************
* FUNCTION PROTOTYPES
*************************************************************************
*/

int GoToTrace(FILE *, long, int);
int GoToByte(FILE *,unsigned long);
long int GetBytes(unsigned char *,int);
int GetTraceSamples(FILE *, TRCSAMPLES *);
int GetCDP(FILE *,long,long *);
int Get4Bytes(FILE *,long,long *);
int Get2Bytes(FILE *,long,int *);
int GetSampRate(FILE *,long,float *);
int GetNumberSamples(FILE *,long,int *);
int GetEBCDICHeader(unsigned char *,EBCDIC *);
int GetBinaryHeader(unsigned char *, BINHEADER *);
int GetTraceHeader(unsigned char *, TRCHEADER *);
float CalcSampleValue(unsigned char *);
